"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.CommandResolverResult = exports.CommandResolver = void 0;
const ValueExtractor_1 = require("./parameters/ValueExtractor");
class CommandResolver {
    constructor(robot) {
        this.robot = robot;
    }
    resolve(res) {
        let tool = null;
        if (this.robot.__tools) {
            tool = this.robot.__tools.find(t => t != null && t.canHandle(res.message.text));
        }
        return this.resolveFromTool(tool, res);
    }
    resolveFromTool(tool, res) {
        if (!res.message.text)
            return null;
        const result = new CommandResolverResult();
        result.user = res.message.user;
        result.text = res.message.text;
        if (tool == null) {
            return result;
        }
        result.tool = tool;
        const matchingCommands = result.tool.commands.filter(cmd => cmd.validationRegex.test(res.message.text));
        if (matchingCommands.length == 0) {
            return result;
        }
        result.command = matchingCommands[0];
        result.authorized =
            (!result.tool.auth || result.tool.auth.length === 0 || result.tool.auth.indexOf(res.message.user.name) > -1) &&
                (!result.command.auth ||
                    result.command.auth.length === 0 ||
                    result.command.auth.indexOf(res.message.user.name) > -1);
        result.match = result.command.validationRegex.exec(res.message.text);
        result.values = (0, ValueExtractor_1.getValues)(this.robot.name, this.robot.alias, result.tool, result.command, res.message.text);
        return result;
    }
}
exports.CommandResolver = CommandResolver;
class CommandResolverResult {
    log(logger) {
        if (logger) {
            const debug = this.getDebugInfo();
            logger.info("Command", debug);
        }
    }
    getDebugInfo() {
        return {
            user: this.user ? this.user.name : null,
            userId: this.user ? this.user.id : null,
            authorized: this.authorized,
            text: this.text,
            tool: this.tool ? this.tool.name : null,
            command: this.command ? this.command.name : null,
            match: this.match,
            values: this.values
        };
    }
}
exports.CommandResolverResult = CommandResolverResult;
