"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.ChoiceParameter = void 0;
const ParameterBase_1 = require("./ParameterBase");
const regex_1 = require("../../utils/regex");
/**
 * Parameter that has a fixed set of values. Remember all values
 * are not case sensitive.
 *
 * @export
 * @class ChoiceParameter
 * @extends {ParameterBase}
 */
class ChoiceParameter extends ParameterBase_1.ParameterBase {
    /**
     * Will only capture the choices.
     *
     * @readonly
     * @memberof ChoiceParameter
     */
    get regex() {
        return `${this.values.map(v => (0, regex_1.escapeRegExp)(v)).join("|")}`;
    }
    /**
     * Creates an instance of ChoiceParameter.
     * @param {string} name The name of the parameter. Can be used to identify the parameter value as well.
     * @param {string[]} values The array of possible values.
     * @param {any} [defaultValue=null] When a value is given, the parameter becomes optional.
     * @memberof ChoiceParameter
     */
    constructor(name, values, defaultValue = null) {
        super(name, defaultValue);
        this.values = values;
        this.defaultValue = defaultValue;
    }
}
exports.ChoiceParameter = ChoiceParameter;
