"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.FractionParameter = void 0;
const NumberStyle_1 = require("./NumberStyle");
const NumberParameter_1 = require("./NumberParameter");
const FractionStyle_1 = require("./FractionStyle");
class FractionParameter extends NumberParameter_1.NumberParameter {
    /**
     * Captures the sign (when specified), both numbers of the
     * fraction and the sperator.
     *
     * @readonly
     * @memberof FractionParameter
     */
    get regex() {
        var r = super.regex + "(";
        if (this.style == FractionStyle_1.FractionStyle.Both) {
            r += "(.|,)";
        }
        else if (this.style == FractionStyle_1.FractionStyle.Comma) {
            r += ",";
        }
        else if (this.style == FractionStyle_1.FractionStyle.Dot) {
            r += ".";
        }
        r += "\\d+)?";
        return r;
    }
    /**
     *Creates an instance of FractionParameter.
     * @param {string} name The name of the parameter.
     * @param {any} [defaultValue=null] When a value is given, the parameter becomes optional.
     * @param {NumberStyle} [numberStyle=NumberStyle.Both] The style of the number (positive, negative, both).
     * @param {FractionStyle} [style=FractionStyle.Both] The style of the fraction (dot, comma or both).
     * @memberof FractionParameter
     */
    constructor(name, defaultValue = null, numberStyle = NumberStyle_1.NumberStyle.Both, style = FractionStyle_1.FractionStyle.Both) {
        super(name, defaultValue, numberStyle);
        this.style = style;
    }
}
exports.FractionParameter = FractionParameter;
