"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.NumberParameter = void 0;
const ParameterBase_1 = require("./ParameterBase");
const NumberStyle_1 = require("./NumberStyle");
/**
 * This parameter will capture natural numbers.
 *
 * @export
 * @class NumberParameter
 * @extends {ParameterBase}
 * @implements {IOptionalParameter}
 */
class NumberParameter extends ParameterBase_1.ParameterBase {
    /**
     * Captures the optional minus sign, as well
     * as the whole number.
     *
     * @readonly
     * @memberof NumberParameter
     */
    get regex() {
        var r = "\\d+";
        if (this.numberStyle == NumberStyle_1.NumberStyle.Negative) {
            r = "-" + r;
        }
        else if (this.numberStyle == NumberStyle_1.NumberStyle.Both) {
            r = "-?" + r;
        }
        return r;
    }
    /**
     * Creates an instance of NumberParameter.
     * @param {string} name The name of the parameter. Can be used to identify the parameter value as well.
     * @param {any} [defaultValue=null] When a value is given, the parameter becomes optional.
     * @memberof NumberParameter
     */
    constructor(name, defaultValue = null, numberStyle = NumberStyle_1.NumberStyle.Both) {
        super(name, defaultValue);
        this.numberStyle = numberStyle;
    }
}
exports.NumberParameter = NumberParameter;
