"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.alias = exports.map_tool = exports.map_command = exports.mapper = exports.map_default_alias = exports.addDiagnosticsMiddleware = exports.removeMarkdownFromIncomingMessages = exports.removeTrailingBotWhitespaceCharactersFromIncomingMessages = exports.removeTrailingWhitespaceCharactersFromIncomingMessages = exports.defaultOptions = exports.Options = exports.IPv4Parameter = exports.TokenParameter = exports.RegExParameter = exports.RegExStringParameter = exports.ChoiceParameter = exports.StringParameter = exports.AnyParameter = exports.RestParameter = exports.FractionStyle = exports.FractionParameter = exports.NumberStyle = exports.NumberParameter = void 0;
const addDiagnosticsMiddleware_1 = require("./middleware/addDiagnosticsMiddleware");
Object.defineProperty(exports, "addDiagnosticsMiddleware", { enumerable: true, get: function () { return addDiagnosticsMiddleware_1.addDiagnosticsMiddleware; } });
const alias_1 = require("./mappers/alias");
const AnyParameter_1 = require("./entities/parameters/AnyParameter");
Object.defineProperty(exports, "AnyParameter", { enumerable: true, get: function () { return AnyParameter_1.AnyParameter; } });
const ChoiceParameter_1 = require("./entities/parameters/ChoiceParameter");
Object.defineProperty(exports, "ChoiceParameter", { enumerable: true, get: function () { return ChoiceParameter_1.ChoiceParameter; } });
const options_1 = require("./entities/options");
Object.defineProperty(exports, "defaultOptions", { enumerable: true, get: function () { return options_1.defaultOptions; } });
Object.defineProperty(exports, "Options", { enumerable: true, get: function () { return options_1.Options; } });
const FractionParameter_1 = require("./entities/parameters/FractionParameter");
Object.defineProperty(exports, "FractionParameter", { enumerable: true, get: function () { return FractionParameter_1.FractionParameter; } });
const FractionStyle_1 = require("./entities/parameters/FractionStyle");
Object.defineProperty(exports, "FractionStyle", { enumerable: true, get: function () { return FractionStyle_1.FractionStyle; } });
const IPv4Parameter_1 = require("./entities/parameters/IPv4Parameter");
Object.defineProperty(exports, "IPv4Parameter", { enumerable: true, get: function () { return IPv4Parameter_1.IPv4Parameter; } });
const map_command_1 = require("./mappers/map_command");
const map_default_alias_1 = require("./mappers/map_default_alias");
Object.defineProperty(exports, "map_default_alias", { enumerable: true, get: function () { return map_default_alias_1.map_default_alias; } });
const map_tool_1 = require("./mappers/map_tool");
const NumberParameter_1 = require("./entities/parameters/NumberParameter");
Object.defineProperty(exports, "NumberParameter", { enumerable: true, get: function () { return NumberParameter_1.NumberParameter; } });
const NumberStyle_1 = require("./entities/parameters/NumberStyle");
Object.defineProperty(exports, "NumberStyle", { enumerable: true, get: function () { return NumberStyle_1.NumberStyle; } });
const RegExStringParameter_1 = require("./entities/parameters/RegExStringParameter");
Object.defineProperty(exports, "RegExParameter", { enumerable: true, get: function () { return RegExStringParameter_1.RegExParameter; } });
Object.defineProperty(exports, "RegExStringParameter", { enumerable: true, get: function () { return RegExStringParameter_1.RegExStringParameter; } });
const removeMarkdownFromIncomingMessages_1 = require("./middleware/removeMarkdownFromIncomingMessages");
Object.defineProperty(exports, "removeMarkdownFromIncomingMessages", { enumerable: true, get: function () { return removeMarkdownFromIncomingMessages_1.removeMarkdownFromIncomingMessages; } });
const removeTrailingBotWhitespaceCharactersFromIncomingMessages_1 = require("./middleware/removeTrailingBotWhitespaceCharactersFromIncomingMessages");
Object.defineProperty(exports, "removeTrailingBotWhitespaceCharactersFromIncomingMessages", { enumerable: true, get: function () { return removeTrailingBotWhitespaceCharactersFromIncomingMessages_1.removeTrailingBotWhitespaceCharactersFromIncomingMessages; } });
const removeTrailingWhitespaceCharactersFromIncomingMessages_1 = require("./middleware/removeTrailingWhitespaceCharactersFromIncomingMessages");
Object.defineProperty(exports, "removeTrailingWhitespaceCharactersFromIncomingMessages", { enumerable: true, get: function () { return removeTrailingWhitespaceCharactersFromIncomingMessages_1.removeTrailingWhitespaceCharactersFromIncomingMessages; } });
const RestParameter_1 = require("./entities/parameters/RestParameter");
Object.defineProperty(exports, "RestParameter", { enumerable: true, get: function () { return RestParameter_1.RestParameter; } });
const StringParameter_1 = require("./entities/parameters/StringParameter");
Object.defineProperty(exports, "StringParameter", { enumerable: true, get: function () { return StringParameter_1.StringParameter; } });
const TokenParameter_1 = require("./entities/parameters/TokenParameter");
Object.defineProperty(exports, "TokenParameter", { enumerable: true, get: function () { return TokenParameter_1.TokenParameter; } });
/**
 * Maps the specified tool to the Robot.
 *
 * @export
 * @param {NodeModule} caller The caller.
 * @param {NodeModule} packageModule The package module.
 * @param {IRobot} robot The robot.
 * @param {ITool} tool The tool that will be mapped.
 * @param {IOptions} [options] The options for this specific mapping.
 */
function mapper(robot, tool, options = options_1.defaultOptions) {
    (0, map_tool_1.map_tool)(robot, tool, options);
}
exports.mapper = mapper;
/**
 * Creates a mapping for a single command.
 *
 * @export
 * @param {Hubot.Robot} robot The robot.
 * @param {string} command The command.
 * @param {(...(IParameter | ICallback | IOptions)[])} args You can specify parameters, the callback and options here.
 */
function map_command(robot, command, ...args) {
    (0, map_command_1.map_command)(robot, command, args);
}
exports.map_command = map_command;
/**
 * Maps the specified tool to the Robot.
 *
 * @param robot The robot.
 * @param tool The tool.
 * @param options The options.
 */
function map_tool(robot, tool, options = options_1.defaultOptions) {
    mapper(robot, tool, options);
}
exports.map_tool = map_tool;
/**
 * Maps a list of alias commands to the Robot.
 *
 * @export
 * @param {Hubot.Robot} robot The robot.
 * @param {*} map An object with keys and redirects.
 * @param {IOptions} [options=defaultOptions] The options.
 */
function alias(robot, map) {
    (0, alias_1.alias)(robot, map);
}
exports.alias = alias;
