"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.alias = void 0;
const regex_1 = require("../utils/regex");
class AliasMapping {
    constructor(map, robot) {
        this.splitter = createBotCommandExtractor(robot.name, robot.alias || robot.name);
        this.matchers = convertMapIntoRegularExpression(map);
    }
    process(text) {
        const data = this.splitter.exec(text);
        if (!data)
            return text;
        const command = data[3];
        const alias = this.matchers.find(m => m.matcher.test(command));
        if (!alias)
            return text;
        const bot = data[1];
        let newText = bot + alias.value;
        const match = alias.matcher.exec(command);
        if (match.length > 1)
            newText = newText + " " + match[1];
        return newText;
    }
    canHandle(msg) {
        const data = this.splitter.exec(msg);
        if (!data)
            return false;
        const command = data[3];
        const alias = this.matchers.find(m => m.matcher.test(command));
        if (!alias)
            return false;
        return true;
    }
}
function alias(robot, map) {
    if (!robot)
        throw "Argument 'robot' is empty.";
    if (!map)
        throw "Argument 'map' is empty.";
    if (robot.logger) {
        Object.keys(map).forEach(key => robot.logger.info(`Aliasing '${key}' to '${map[key]}'.`));
    }
    var mapping = new AliasMapping(map, robot);
    //TODO: do wee need to add this to the tools?
    //without it the map_default_alias will not work
    var bot = robot;
    bot.__tools = bot.__tools || [];
    bot.__tools.push(mapping);
    robot.receiveMiddleware(async (context) => {
        var text = context.response.message.text;
        var newText = mapping.process(text);
        if (text != newText) {
            context.response.message.text = newText;
            if (robot.logger) {
                robot.logger.info(`Routing '${text}' to '${newText}'.`);
            }
        }
        return true;
    });
}
exports.alias = alias;
/**
 * Creates a regular expression that can extract the bot name and the
 * rest of the command.
 *
 * @export
 * @param {string} name The name of the bot.
 * @param {string} alias The alias of the bot.
 * @returns {RegExp} The regular expression.
 */
function createBotCommandExtractor(name, alias) {
    return new RegExp(`^(@?(${(0, regex_1.escapeRegExp)(name)}|${(0, regex_1.escapeRegExp)(alias)}) )(.*)$`, "i");
}
function convertMapIntoRegularExpression(map) {
    return Object.keys(map).map(key => {
        let value = map[key];
        let regex = key.endsWith("*")
            ? new RegExp(`^${(0, regex_1.escapeRegExp)(key.substr(0, key.length - 1))} (.+)$`, "i")
            : new RegExp(`^${(0, regex_1.escapeRegExp)(key)}$`, "i");
        return new RegularExpressionMap(regex, value);
    });
}
class RegularExpressionMap {
    constructor(matcher, value) {
        this.matcher = matcher;
        this.value = value;
    }
}
